OC.L10N.register(
    "deck",
    {
    "Personal" : "පෞද්ගලික",
    "Done" : "Done",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "උඩුගත කළ ගොනුවේ විශාලත්වය HTML පෝරමයේ නියම කළ ඇති MAX_FILE_SIZE විශාලත්වයට වඩා වැඩිය",
    "No file was uploaded" : "ගොනුවක් උඩුගත නොවුණි",
    "Missing a temporary folder" : "තාවකාලික ෆොල්ඩරයක් අතුරුදහන්",
    "Cancel" : "අවලංගු කරන්න",
    "Sharing" : "හුවමාරු කිරීම",
    "Tags" : "ටැග",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Delete" : "ඉවත් කරන්න",
    "Edit" : "සකසන්න",
    "Title" : "මාතෘකාව",
    "Description" : "විස්තරය",
    "Comments" : "අදහස්",
    "Modified" : "වෙනස් කළ",
    "Save" : "සුරකින්න",
    "Update" : "යාවත්කාල කිරීම",
    "seconds ago" : "තත්පරයන්ට පෙර",
    "Shared with you" : "Shared with you",
    "Settings" : "සැකසුම්"
},
"nplurals=2; plural=(n != 1);");
